#!/usr/bin/env python

### setup.py

from distutils.core import setup

setup(name='DecisionTree',
      version='1.6',
      author='Avinash Kak',
      author_email='kak@purdue.edu',
      maintainer='Avinash Kak',
      maintainer_email='kak@purdue.edu',
      url='https://engineering.purdue.edu/kak/distDT/DecisionTree-1.6.html',
      download_url='https://engineering.purdue.edu/kak/distDT/DecisionTree-1.6.tar.gz?download',
      description='A pure-Python implementation for constructing a decision tree from multidimensional training data and for using the decision tree for classifying unlabeled data',
      long_description=''' 

**Version 1.6** includes several upgrades: The module now
includes code for generating synthetic training and test
data for experimenting with the decision tree classifier.
For another upgrade, the classifier can now be used in an
interactive mode.  In this mode, after you have constructed
a decision tree, the user is prompted for answers to the
questions pertaining to the feature tests at the nodes.

**Version 1.5** should work with both Python 3.x and Python 2.x.

Assuming you have arranged your training data in the form of
a table in a text file, all you have to do is to supply the
name of the training datafile to this module and it does the
rest for you without much effort on your part.  A decision
tree classifier consists of feature tests that are arranged
in the form of a tree. The feature test associated with the
root node is one that can be expected to maximally
disambiguate the different possible class labels for an
unlabeled data record.  From the root node hangs a set of
child nodes, one for each value of the feature at the root
node.  At each such child node, a feature test is selected
that is the most class discriminative given that you have
already applied the feature test at the root node and
observed the value for that feature.  This process is
continued until you reach the leaf nodes of the tree.  The
leaf nodes may either correspond to the maximum depth
desired for the decision tree or to the case when you run
out of features to test.

Typical usage syntax:

        dt = DecisionTree( training_datafile = "training.dat", debug1 = 1 )

        dt.get_training_data()

        dt.show_training_data()

        root_node = dt.construct_decision_tree_classifier()

        root_node.display_decision_tree("   ")

        test_sample = ['exercising=>never', 'smoking=>heavy', 
                       'fatIntake=>heavy', 'videoAddiction=>heavy']

        classification = dt.classify(root_node, test_sample)

        print "Classification: ", classification

          ''',

      license='Python Software Foundation License',
      keywords='data classification, decision trees, information analysis',
      platforms='All platforms',
      classifiers=['Topic :: Scientific/Engineering :: Information Analysis'],
      packages=['']
)
